Package: tectonicr
Title: Analyzing the Orientation of Maximum Horizontal Stress
Version: 0.4.9
Authors@R: 
    person("Tobias", "Stephan", , "tobias.stephan1@yahoo.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-9290-014X"))
Description: Models the direction of the maximum horizontal stress using
    relative plate motion parameters. Statistical algorithms to evaluate
    the modeling results compared with the observed data. Provides plots
    to visualize the results. Methods described in Stephan et al. (2023)
    <doi:10.1038/s41598-023-42433-2> and Wdowinski (1998)
    <doi:10.1016/S0079-1946(98)00091-3>.
License: GPL (>= 3)
URL: https://tobiste.github.io/tectonicr/
BugReports: https://github.com/tobiste/tectonicr/issues
Depends: R (>= 4.1.0)
Imports: boot, circular (>= 0.5.0), dplyr, ggplot2, lifecycle, methods,
        RColorBrewer, sf, smoothr (>= 1.0.1), spatstat.explore (>=
        3.2.7), spatstat.geom (>= 3.2.9), spatstat.univar (>= 2.0.3),
        spatstat.utils (>= 3.0.4), terra, tidyr, viridis, zoo (>=
        1.8.12)
Suggests: ggforce, grid, knitr, rmarkdown, roxygen2, testthat (>=
        3.0.0), tidyterra
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-08-28 19:34:50 UTC; tstephan
Author: Tobias Stephan [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9290-014X>)
Maintainer: Tobias Stephan <tobias.stephan1@yahoo.com>
Repository: CRAN
Date/Publication: 2026-08-29 12:50:02 UTC
Built: R 4.5.2; ; 2026-08-29 14:34:45 UTC; unix
