# Generated by roxygen2: do not edit by hand

export(PoR2Geo_azimuth)
export(PoR_azimuth)
export(PoR_coordinates)
export(PoR_crs)
export(PoR_distance)
export(PoR_map)
export(PoR_shmax)
export(PoR_stress2grid)
export(PoR_stress2grid_stats)
export(PoR_to_geographical)
export(PositionCenterSpoke)
export(abs_vel)
export(angle_vectors)
export(ar_test)
export(atan2_spec)
export(atan2d_spec)
export(axes)
export(axial_dispersion)
export(axial_strength)
export(cartesian_to_geographical)
export(cartesian_to_spherical)
export(circular_IQR)
export(circular_density)
export(circular_dispersion)
export(circular_dispersion_boot)
export(circular_distance)
export(circular_mean)
export(circular_mean_difference)
export(circular_mean_difference_alt)
export(circular_median)
export(circular_mode)
export(circular_plot)
export(circular_qqplot)
export(circular_quantiles)
export(circular_range)
export(circular_sample_median)
export(circular_sample_median_deviation)
export(circular_sd)
export(circular_sd2)
export(circular_sd_error)
export(circular_summary)
export(circular_var)
export(compact_grid)
export(compact_grid2)
export(confidence_angle)
export(confidence_interval)
export(confidence_interval_fisher)
export(data2PoR)
export(dcunif)
export(deg2rad)
export(deviation_norm)
export(deviation_shmax)
export(dispersion_grid)
export(dist_greatcircle)
export(distance_binned_stats)
export(distance_from_pb)
export(distroll_circstats)
export(distroll_confidence)
export(distroll_dispersion)
export(distroll_dispersion_sde)
export(download_WSM)
export(download_WSM2016)
export(dvm)
export(dwcauchy)
export(dwnorm)
export(earth_radius)
export(equivalent_rotation)
export(est.kappa)
export(est.kappa.MLE)
export(euler_pole)
export(eulerpole_greatcircles)
export(eulerpole_loxodromes)
export(eulerpole_paths)
export(eulerpole_smallcircles)
export(geographical_to_PoR)
export(geographical_to_cartesian)
export(geographical_to_spherical)
export(geom_azimuth)
export(geom_azimuthpoint)
export(get_azimuth)
export(haversine)
export(kernel_dispersion)
export(kuiper_test)
export(latitude_modulo)
export(line_azimuth)
export(lines_azimuths)
export(load_WSM)
export(load_WSM2016)
export(longitude_modulo)
export(mean_resultant_length)
export(model_shmax)
export(norm_chisq)
export(ortensor2d)
export(orthodrome)
export(ot_eigen2d)
export(parse_wsm_quality)
export(pcunif)
export(plot_density)
export(plot_points)
export(prd_err)
export(principal_direction)
export(projected_pb_strike)
export(pvm)
export(pwcauchy)
export(pwnorm)
export(qcunif)
export(quantise_wsm_quality)
export(quick_plot)
export(qvm)
export(qwcauchy)
export(qwnorm)
export(rad2deg)
export(rayleigh_test)
export(rayleigh_test_perm)
export(rcunif)
export(relative_rotation)
export(roll_circstats)
export(roll_confidence)
export(roll_dispersion)
export(roll_dispersion_CI)
export(roll_dispersion_sde)
export(roll_normchisq)
export(roll_rayleigh)
export(rose)
export(rose_fan)
export(rose_line)
export(rose_stats)
export(rvm)
export(rwcauchy)
export(rwnorm)
export(sample_circular_dispersion)
export(sample_circular_distance)
export(sample_circular_variance)
export(second_central_moment)
export(shortest_distance_to_line)
export(spherical_to_cartesian)
export(spherical_to_geographical)
export(stress2grid)
export(stress2grid_stats)
export(stress_analysis)
export(stress_colors)
export(superimposed_shmax)
export(superimposed_shmax_PB)
export(tectonicr.colors)
export(vcross)
export(vincenty)
export(vm_qqplot)
export(watson_test)
export(watson_two_test)
export(watson_two_test_perm)
export(watson_wheeler_test_perm)
export(weighted_rayleigh)
export(weighted_rayleigh_perm)
export(weighting)
import(spatstat.explore)
import(spatstat.utils)
importFrom(RColorBrewer,brewer.pal)
importFrom(boot,boot)
importFrom(boot,boot.ci)
importFrom(circular,circular)
importFrom(circular,daxialvonmises)
importFrom(circular,meandeviation)
importFrom(circular,median.circular)
importFrom(circular,pvonmises)
importFrom(circular,pwrappednormal)
importFrom(circular,qvonmises)
importFrom(circular,qwrappednormal)
importFrom(circular,rvonmises)
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,between)
importFrom(dplyr,bind_cols)
importFrom(dplyr,case_when)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,rename_with)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(ggplot2,Position)
importFrom(ggplot2,alpha)
importFrom(ggplot2,cut_number)
importFrom(ggplot2,cut_width)
importFrom(ggplot2,ggproto)
importFrom(graphics,abline)
importFrom(graphics,hist)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(lifecycle,deprecated)
importFrom(methods,extends)
importFrom(sf,as_Spatial)
importFrom(sf,st_as_sf)
importFrom(sf,st_bbox)
importFrom(sf,st_cast)
importFrom(sf,st_coordinates)
importFrom(sf,st_crs)
importFrom(sf,st_drop_geometry)
importFrom(sf,st_geometry)
importFrom(sf,st_make_grid)
importFrom(sf,st_set_crs)
importFrom(sf,st_transform)
importFrom(sf,st_wrap_dateline)
importFrom(smoothr,densify)
importFrom(spatstat.explore,rose)
importFrom(spatstat.geom,disc)
importFrom(spatstat.geom,plot.owin)
importFrom(spatstat.univar,whist)
importFrom(spatstat.utils,short.deparse)
importFrom(stats,aggregate)
importFrom(stats,ecdf)
importFrom(stats,na.omit)
importFrom(stats,qnorm)
importFrom(stats,rcauchy)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(terra,crs)
importFrom(terra,project)
importFrom(terra,rast)
importFrom(tidyr,drop_na)
importFrom(utils,download.file)
importFrom(utils,read.csv)
importFrom(viridis,viridis)
importFrom(zoo,rollapply)
